@@ -7,7 +7,7 @@
    This program was developed for use in
    gpsman --- GPS Manager: a manager for GPS receiver data
 
-   Copyright (c) 2003-2011 Miguel Filgueiras (migf@portugalmail.pt)
+   Copyright (c) 2003-2013 Miguel Filgueiras (migfilg@t-online.de)
 
     This program is free software; you can redistribute it and/or modify
       it under the terms of the GNU General Public License as published by
@@ -50,6 +50,10 @@
 
 -----
 Revision history:
+1.2.3   06-Oct-13
+         change of author email address
+1.2.2   15-Jul-13
+         change of author email address
 1.2.1   08-Jun-11
          path to shapefil.h
          change of author email address
@@ -66,14 +70,14 @@ Revision history:
 \*---------------------------------------------------------------------------*/
 
 /* File: gpsmanshp.c *\
-\* Last modified: 8 June 2011 */
+\* Last modified: 15 July 2013 */
 
 #include <stdlib.h>
 #include <string.h>
 #include <shapefil.h>
 #include <tcl.h>
 
-#define VERSION "1.2.1"
+#define VERSION "1.2.3"
 
 // #define DEBUG 1
 
