@@ -6,7 +6,7 @@
    This program was developed for use with
    gpsman --- GPS Manager: a manager for GPS receiver data
 
-   Copyright (c) 2002-2011 Miguel Filgueiras (mig@portugalmail.pt)
+   Copyright (c) 2002-2013 Miguel Filgueiras (migfilg@t-online.de)
 
     This program is free software; you can redistribute it and/or modify
       it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 \*---------------------------------------------------------------------------*/
 
 /* File: gentr2shp.c *\
-\* Last modified: 8 June 2011 */
+\* Last modified: 6 October 2013 */
 
 
 /* Format of GPStrans files:
